import Vue from 'vue'
import axios from 'axios';
import qs from 'qs';
import baseConfig from './config';
import Cookies from "js-cookie";
import {
  Message
} from 'element-ui';
// 使用vuex做全局loading时使用

const formatParams = obj => {
  let newParams = new URLSearchParams();
  if (obj) {
    Object.keys(obj).forEach(key => {
      newParams.append(key, obj[key]);
    });
  }
  return newParams;
};

export default function $axios(options) {

  let config = baseConfig();

  let baseUrl = options.baseUrl || config.baseUrl,
    headers = options.headers || config.headers,
    timeout = options.timeout || config.timeout,
    toastError = options.toastError == false ? options.toastError : config.toastError,
    withCredentials = options.withCredentials || config.withCredentials;
  return new Promise((resolve, reject) => {
    const instance = axios.create({
      baseURL: baseUrl,
      headers: headers,
      timeout: timeout,
      withCredentials: withCredentials,
      toastError: toastError
    })

    // request 拦截器
    instance.interceptors.request.use(
      config => {
        let token = sessionStorage.getItem('jssk.frame.token') || Cookies.get('token'), resortId = sessionStorage.getItem("jssk.frame.resortId");

        // 1. 请求开始的时候可以结合 vuex 开启全屏 loading 动画
        // console.log(store.state.loading)
        // console.log('准备发送请求...')
        // 2. 带上token
        if (token) {
          if (!options.Hardware) {
            if (options.url != 'oauth2/authorize/login') {
              config.headers['Authorization'] = 'Bearer ' + token;
              config.headers['INSTITUTIONID'] = resortId;
              config.headers['RESORTID'] = resortId;
            }
          }
        } else {
          Vue.prototype.$vueRoute.push('/login');
        }


        if (config.method.toUpperCase() === 'GET') {
          let parastr = qs.stringify(config.data);
          if (parastr) {
            config.url = config.url + '?' + parastr
          }
        }

        if (headers["Content-Type"] == 'application/x-www-form-urlencoded') {
          if (!options.Hardware) {
            config.data = formatParams(config.data)
          }
        } else if ("multipart/form-data" === headers["Content-Type"]) {
          let formData = new FormData();
          for (let i in config.data) {
            if (i != 'files') {
              formData.append(i, config.data[i])
            }
          }
          if (config.data['files'] && config.data['files'].length > 0) {
            config.data['files'].forEach(item => {
              formData.append('files', item)
            })
          }
          config.data = formData;
        }
        return config
      },

      error => {
        // 请求错误时
        console.log('request:', error)
        // 1. 判断请求超时
        if (error.code === 'ECONNABORTED' && error.message.indexOf('timeout') !== -1) {
          console.log('timeout请求超时')
          // return service.request(originalRequest);// 再重复请求一次
        }
        // 2. 需要重定向到错误页面
        const errorInfo = error.response
        console.log(errorInfo)
        if (errorInfo) {
          error = errorInfo.data // 页面那边catch的时候就能拿到详细的错误信息,看最下边的Promise.reject
          const errorStatus = errorInfo.status; // 404 403 500 ...
          Vue.prototype.$vueRoute.push({
            path: `/error/${errorStatus}`
          })
        }
        return Promise.reject(error) // 在调用的那边可以拿到(catch)你想返回的错误信息
      }
    )

    // response 拦截器
    instance.interceptors.response.use(
      response => {
        let data;
        // IE9时response.data是undefined，因此需要使用response.request.responseText(Stringify后的字符串)
        if (response.data == undefined) {
          data = JSON.parse(response.request.responseText)

        } else {
          data = response.data
        }

        if (data.code == '10002') {
          // Cookies.remove('token');
          sessionStorage.clear();
          setTimeout(function () {
            Vue.prototype.$vueRoute.push("/login");
          }, 1000)
        }
        return data
      },
      err => {
        console.log(err)
        if (err && err.response) {
          switch (err.response.status) {
            case 400:
              err.message = '请求错误'
              break
            case 401:
              err.message = '登录超时，请重新登录';
              Cookies.remove('token');
              sessionStorage.clear();
              setTimeout(function () {
                Vue.prototype.$vueRoute.push("/login");
              }, 1000)
              break
            case 403:
              err.message = '拒绝访问'
              break
            case 404:
              err.message = `请求地址出错`
              break
            case 408:
              err.message = '请求超时'
              break
            case 500:
              // 优先提示接口返回的错误信息
              err.message = err.response.data.message || '服务器内部错误'
              break
            case 501:
              err.message = '服务未实现'
              break
            case 502:
              err.message = '网关错误'
              break
            case 503:
              err.message = '服务不可用'
              break
            case 504:
              err.message = '网关超时'
              break
            case 505:
              err.message = 'HTTP版本不受支持'
              break
            default:
              err.message = '网络错误，请重试'
              break;
          }
        } else {
          err.message = '网络错误，请重试'
        }
        if (toastError) {
          let flag = sessionStorage.getItem('jssk.frame.errFlag');
          if (!flag || flag == "false") {
            Message.error({
              message: err.message,
              offset: 80,
              duration: 1200
            });
            sessionStorage.setItem('jssk.frame.errFlag', true);
            setTimeout(() => {
              sessionStorage.setItem('jssk.frame.errFlag', false);
            }, 1000)
          }

        }
        return Promise.reject(err) // 返回接口返回的错误信息
      }
    )

    // 请求处理
    instance(options).then(res => {
      resolve(res)
      return false
    }).catch(error => {
      reject(error)
    })
  })
}
