export function validateIP(rule, value,callback) {
  if(value==''||value==undefined||value==null){
    callback();
  }else {
    const reg = /^(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/;
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的IP地址'));
    } else {
      callback();
    }
  }
}
//不能输入中文
export function notChineseCharacters(rule, value, callback) {
  const reg =/[\u4E00-\u9FA5]/;
  if(value==''||value==undefined||value==null){
    callback();
  } else {
    if (reg.test(value)){
      callback(new Error('不能输入汉字'));
    } else {
      callback();
    }
  }
}

/* 是否手机号码或者固话*/
export function validatePhoneTwo(rule, value, callback) {
  const reg = /^((0\d{2,3}-\d{7,8})|(1[34578]\d{9}))$/;;
  if (value == '' || value == undefined || value == null) {
    callback();
  } else {
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的电话号码或者固话号码'));
    } else {
      callback();
    }
  }
}

export function validateEndDate(rule, value, callback,form){
  const endType = form.endType;
  const beginDate = new Date(form.licenseBeginDate);
  const endDate = new Date(value);
  if(endDate < beginDate && !endType){
    callback(new Error('结束日期不能小于开始日期'));
  }
  if(!value && !endType){
    callback(new Error('请选择结束日期或选择不限制使用日期'));
  }
  callback();
}

/* 是否固话*/
export function validateTelphone(rule, value,callback) {
  const reg =/0\d{2}-\d{7,8}/;
  if(value==''||value==undefined||value==null){
    callback();
  }else {
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的固话（格式：区号+号码,如010-1234567）'));
    } else {
      callback();
    }
  }
}
/* 是否手机号码*/
export function validatePhone(rule, value,callback) {
  const reg =/^(((13[0-9]{1})|(15[0-9]{1})|(16[0-9]{1})|(17[3-8]{1})|(18[0-9]{1})|(19[0-9]{1})|(14[5-7]{1}))+\d{8})$/;
  if(value==''||value==undefined||value==null){
     callback();
  }else {
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的电话号码'));
    } else {
      callback();
    }
  }
}

/* 是否手机号码*/
export function validateMobile(rule, value,callback) {
  const reg =/^1[0-9]{10}$/;
  if(value==''||value==undefined||value==null){
    callback();
  }else {
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的电话号码'));
    } else {
      callback();
    }
  }
}
/* 是否身份证号码*/
export function validateIdNo(rule, value,callback) {
  const reg = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/;
  if(value==''||value==undefined||value==null){
    callback();
  }else {
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的身份证号码'));
    } else {
      callback();
    }
  }
}
/* 是否是护照*/
export function validatePassPort(rule, value,callback) {
  const reg = /^1[45][0-9]{7}$|(^[P|p|S|s]\d{7}$)|(^[S|s|G|g|E|e]\d{8}$)|(^[Gg|Tt|Ss|Ll|Qq|Dd|Aa|Ff]\d{8}$)|(^[H|h|M|m]\d{8,10}$)/;
  if(value==''||value==undefined||value==null){
    callback();
  }else {
    if ((!reg.test(value)) && value != '') {
      callback(new Error('请输入正确的护照号码'));
    } else {
      callback();
    }
  }
}
/* 是否邮箱*/
export function validateEMail(rule, value,callback) {
  const reg =/^([a-zA-Z0-9]+[-_\.]?)+@[a-zA-Z0-9]+\.[a-z]+$/;
  if(value==''||value==undefined||value==null){
    callback();
  }else{
    if (!reg.test(value)){
      callback(new Error('请输入正确的邮箱地址'));
    } else {
      callback();
    }
  }
}
/* 合法uri*/
// export function validateURL(textval) {
//   const urlregex = /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/;
//   return urlregex.test(textval);
// }

/* 验证账号  ^[A-Za-z0-9_]|[\b]+$ */
export function validateURL(rule, value, callback) {
  const urlregex = /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/;
  if (!value) {
    return callback()
  }
  setTimeout(() => {
    if (!urlregex.test(value)) {
      return callback(new Error('请输入合法url'))
    } else {
      callback()
    }
  }, 100)
}
/*验证内容是否英文数字以及下划线*/
export function isPassword(rule, value, callback) {
  const reg =/^[_a-zA-Z0-9]+$/;
  if(value==''||value==undefined||value==null){
    callback();
  } else {
    if (!reg.test(value)){
      callback(new Error('密码仅由英文字母，数字以及下划线组成'));
    } else {
      callback();
    }
  }
}
export function isNumAndWord(rule, value, callback) {
  const reg =/^[a-zA-Z0-9]+$/;
  if(value==''||value==undefined||value==null){
    callback();
  } else {
    if (!reg.test(value)){
      callback(new Error('由英文字母，数字组成'));
    } else {
      callback();
    }
  }
}

/*自动检验数值的范围*/
export function checkMax20000(rule, value, callback) {
  if (value == '' || value == undefined || value == null) {
    callback();
  } else if (!Number(value)) {
    callback(new Error('请输入1-20000的数字'));
  } else if (value < 1 || value > 20000) {
    callback(new Error('请输入1-20000的数字'));
  } else {
    callback();
  }
}

//验证数字输入框最大数值,32767
export function checkMaxVal(rule, value,callback) {
  if (value < 0 || value > 32767) {
    callback(new Error('请输入0-32767的数字'));
  } else {
    callback();
  }
}
export function checkMaxUserVal(rule, value,callback,userNum) {
  if (value < 0 || value > userNum) {
    callback(new Error('请输入0-'+userNum+'的数字'));
  } else {
    callback();
  }
}
//验证是否1-99之间
export function isOneToNinetyNine(rule, value, callback) {
  if (!value) {
    return callback(new Error('输入不可以为空'));
  }
  setTimeout(() => {
    if (!Number(value)) {
      callback(new Error('请输入正整数'));
    } else {
      const re = /^[1-9][0-9]{0,1}$/;
      const rsCheck = re.test(value);
      if (!rsCheck) {
        callback(new Error('请输入正整数，值为1-99'));
      } else {
        callback();
      }
    }
  }, 0);
}

// 验证是否整数
export function isInteger(rule, value, callback) {
   if (!value) {
     return callback(new Error('输入不可以为空'));
   }
  setTimeout(() => {
    if (!Number(value)) {
       callback(new Error('请输入正整数'));

    } else {
      const re = /^[0-9]*[1-9][0-9]*$/;
      const rsCheck = re.test(value);
      if (!rsCheck) {
        callback(new Error('请输入正整数'));
      } else {
        callback();
      }
    }
  }, 0);
}
// 验证是否整数,非必填
export function isIntegerNotMust(rule, value, callback) {
  if (!value) {
    callback();
  }
  setTimeout(() => {
    if (!Number(value)) {
      callback(new Error('请输入正整数'));
    } else {
      const re = /^[0-9]*[1-9][0-9]*$/;
      const rsCheck = re.test(value);
      if (!rsCheck) {
        callback(new Error('请输入正整数'));
      } else {
        callback();
      }
    }
  }, 100);
}

// 验证是否是[0-1]的小数
export function isDecimal(rule, value, callback) {
  if (!value) {
    return callback(new Error('输入不可以为空'));
  }
  setTimeout(() => {
    if (!Number(value)) {
      callback(new Error('请输入0-1的数字'));
    } else {
      if (value < 0 || value > 1) {
        callback(new Error('请输入0-1的数字'));
      } else {
        callback();
      }
    }
  }, 100);
}

// 验证是否是[1-10]的小数,即不可以等于0
export function isBtnOneToTen(rule, value, callback) {
  if (typeof value == 'undefined') {
    return callback(new Error('输入不可以为空'));
  }
  setTimeout(() => {
    if (!Number(value)) {
      callback(new Error('请输入正整数，值为1-10'));
    } else {
      if (!(value == '1' || value == '2' || value == '3' || value == '4' || value == '5' || value == '6' || value == '7' || value == '8' || value == '9' || value == '10')) {
        callback(new Error('请输入正整数，值为1-10'));
      } else {
        callback();
      }
    }
  }, 100);
}
// 验证是否是[1-10]的小数,即不可以等于0
export function isBtnOneToHundred(rule, value, callback) {
  if (!value) {
    return callback(new Error('输入不可以为空'));
  }
  setTimeout(() => {
    if (!Number(value)) {
      callback(new Error('请输入整数，值为1-100'));
    } else {
      if (value < 1 || value > 100) {
        callback(new Error('请输入整数，值为1-100'));
      } else {
        callback();
      }
    }
  }, 100);
}
// 验证是否是[0-100]的小数
export function isBtnZeroToHundred(rule, value, callback) {
  if (!value) {
    return callback(new Error('输入不可以为空'));
  }
  setTimeout(() => {
    if (!Number(value)) {
      callback(new Error('请输入1-100的数字'));
    } else {
      if (value < 0 || value > 100) {
        callback(new Error('请输入1-100的数字'));
      } else {
        callback();
      }
    }
  }, 100);
}

// 验证是否是[0-10000]的正数,
export function isPositiveNumber(rule, value, callback) {
  const number = /^[+]{0,1}(\d+)$|^[+]{0,1}(\d+\.\d+)$/
  setTimeout(() => {
    if (!number.test(value)) {
      callback(new Error('不可输入负值'));
    } else {
      if (value <= 0 || value > 10000) {
        callback(new Error('请输入0-10000的数字'));
      } else {
        callback();
      }
    }
  }, 100);
}

// 验证是否是正数[0-10000]的正数,
export function isPositiveNumberNoLimit(rule, value, callback) {
  const number = /^[+]{0,1}(\d+)$|^[+]{0,1}(\d+\.\d+)$/
  setTimeout(() => {
    if (!number.test(value)) {
      callback(new Error('只能输入数字，且不可为负'));
    }else {
      if (value < 0 || value > 10000) {
        callback(new Error('请输入0-10000的数字'));
      }else
      {
      callback();
      }
    }
  }, 100);
}

// 验证是否是正数[0.01-10000]的正数,
export function isPriceNumberNoLimit(rule, value, callback) {
  const number = /^[+]{0,1}(\d+)$|^[+]{0,1}(\d+\.\d+)$/
  setTimeout(() => {
    if (!number.test(value)) {
      callback(new Error('输入不为负的数字'));
    }else {
      if (value < 0.01 || value > 10000) {
        callback(new Error('值为0.01-10000的数'));
      }else
      {
        callback();
      }
    }
  }, 100);
}
// 验证是否是正数[1-1000000]的正数,
export function isPositiveNumberLimitOne(rule, value, callback) {
  const number = /^[+]{0,1}(\d+)$|^[+]{0,1}(\d+\.\d+)$/
  setTimeout(() => {
    if (!number.test(value)) {
      callback(new Error('只能输入数字，且不可为负'));
    }else {
      if (value <= 0 || value > 1000000) {
        callback(new Error('请输入大于0的数字'));
      }else
      {
        callback();
      }
    }
  }, 100);
}

// 验证端口是否在[0,65535]之间
export function isPort(rule, value, callback) {
  if (!value) {
    return callback(new Error('输入不可以为空'));
  }
  setTimeout(() => {
    if (value == '' || typeof(value) == undefined) {
      callback(new Error('请输入端口值'));
    } else {
      const re = /^([0-9]|[1-9]\d|[1-9]\d{2}|[1-9]\d{3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]\d|6553[0-5])$/;
      const rsCheck = re.test(value);
      if (!rsCheck) {
        callback(new Error('请输入在0-65535的端口值'));
      } else {
        callback();
      }
    }
  }, 100);
}

// 验证端口是否在[0,65535]之间，非必填,isMust表示是否必填
export function isCheckPort(rule, value, callback) {
  if (!value) {
    callback();
  }
  setTimeout(() => {
    if (value == '' || typeof(value) == undefined) {
      //callback(new Error('请输入端口值'));
    } else {
      const re = /^([0-9]|[1-9]\d|[1-9]\d{2}|[1-9]\d{3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]\d|6553[0-5])$/;
      const rsCheck = re.test(value);
      if (!rsCheck) {
        callback(new Error('请输入在0-65535的端口值'));
      } else {
        callback();
      }
    }
  }, 100);
}
/* 验证账号  ^[A-Za-z0-9_]|[\b]+$ */
export function validateUsername(rule, value, callback) {
  const emailReg = /^[a-zA-Z][a-zA-Z0-9_]{0,18}$/
  if (!value) {
    return callback(new Error('用户名不能为空'))
  }
  setTimeout(() => {
    if (!emailReg.test(value)) {
      return callback(new Error('只能字母开头，允许1-19位，允许字母数字下划线'))
    } else {
      callback()
    }
  }, 100)
}

/* 4-15 验证角色  只含有汉字、数字、字母、下划线，下划线位置不限 */
export function validateRolename(rule, value, callback) {
  const roleNameReg = /^[a-zA-Z0-9_\u4e00-\u9fa5]{4,15}$/
  if (!value) {
    return callback(new Error('角色名不能为空'))
  }
  setTimeout(() => {
    if (!roleNameReg.test(value)) {
      return callback(new Error('只能汉字、数字、字母、下划线组成，4-15位'))
    } else {
      callback()
    }
  }, 100)
}

/* 4-15 验证角色  只含有汉字、数字、字母、下划线，下划线位置不限 */
export function validateOtherName(rule, value, callback) {
  const roleNameReg = /^[a-zA-Z0-9_\u4e00-\u9fa5]{2,30}$/
  if (!value) {
    return callback(new Error('角色名不能为空'))
  }
  setTimeout(() => {
    if (!roleNameReg.test(value)) {
      return callback(new Error('只能汉字、数字、字母、下划线组成，2-30位'))
    } else {
      callback()
    }
  }, 100)
}

/* 验证密码 */
export function validatePassword(rule, value, callback) {
  if (value.length < 6) {
    return callback(new Error('密码不能小于6位'))
  } else {
    callback()
  }
}

/* 合法邮箱 */
export function validateEmail(rule, value, callback) {
  const emailReg = /^(([a-zA-Z0-9_\-\.]+)@([a-zA-Z0-9_\-\.]+)\.([a-zA-Z]{2,5}){1,25})$/
  if (!value) {
    return callback()
  }
  setTimeout(() => {
    if (!emailReg.test(value)) {
      return callback(new Error('邮箱格式错误'))
    } else {
      callback()
    }
  }, 100)
}


/* 合法真实姓名 */
export function validateRealName(rule, value, callback) {
  const realnameReg = /^([a-zA-Z\u4e00-\u9fa5\·]{1,10})$/
  if (!value) {
    return callback(new Error('真实姓名不能为空!!'))
  }
  setTimeout(() => {
    if (!realnameReg.test(value)) {
      return callback(new Error('您的真实姓名格式错误,请输入1-10位长度的英文或汉字'))
    } else {
      callback()
    }
  }, 100)
}

/* 合法身份证 */
export function validateIdNumber(rule, value, callback) {
  const idNumberReg = /^[1-9]\d{7}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}$|^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}([0-9]|X)$/
  if (!value) {
    return callback(new Error('身份证号码不能为空!!'))
  }
  setTimeout(() => {
    if (!idNumberReg.test(value)) {
      return callback(new Error('您的身份证号码格式错误!'))
    } else {
      callback()
    }
  }, 100)
}

/* 小写字母*/
export function validateLowerCase(str) {
  const reg = /^[a-z]+$/;
  return reg.test(str);
}
/*保留2为小数*/
export function validatetoFixedNew(str) {
  return str ;
}
/* 验证key*/
// export function validateKey(str) {
//     var reg = /^[a-z_\-:]+$/;
//     return reg.test(str);
// }

/* 大写字母*/
export function validateUpperCase(str) {
  const reg = /^[A-Z]+$/;
  return reg.test(str);
}

/* 大小写字母*/
export function validatAlphabets(str) {
  const reg = /^[A-Za-z]+$/;
  return reg.test(str);
}

// 验证是否是正数[1-9999]的正数,
export function isPeopleNumberLimit(rule, value, callback) {
  const number = /^[+]{0,1}(\d+)$|^[+]{0,1}(\d+\.\d+)$/
  setTimeout(() => {
    const re = /^[0-9]*[1-9][0-9]*$/;
    const rsCheck = re.test(value);
    if (!rsCheck) {
      callback(new Error('请输入正整数'));
    }else if (!number.test(value)) {
      callback(new Error('只能输入数字，且不可为负'));
    }else {
      if (value <= 0 || value > 9999) {
        callback(new Error('请输入1-9999的数字'));
      }else
      {
        callback();
      }
    }
  }, 100);
}

// 验证是否是非负整数,
export function isPeopleNumberLimits(rule, value, callback) {
  setTimeout(() => {
    const re = /^\d+$/;
    const rsCheck = re.test(value);
    if (!rsCheck) {
      callback(new Error('请输入正整数（包含0）'));
    }else {
      callback();
    }
  }, 100);
}

// 验证是否是正数[1-60]的正数,
export function isPeopleNumberLimitdate(rule, value, callback) {
  console.log(value)
  setTimeout(() => {
    const re = /^\d+$/;
    const rsCheck = re.test(value);
    if (!rsCheck) {
      callback(new Error('请输入正整数'));
    } else {
      if (value <= 0 || value > 60) {
        callback(new Error('请输入1-60的数字'));
      } else {
        callback();
      }
    }
  }, 100);
}


/* 4-15 验证角色  只含有汉字、数字、字母、下划线，下划线位置不限 */
export function validateDistributeType(rule, value, callback) {
  if (!value) {
    return callback(new Error('请选择分销商类型'));
  }else{
  callback();
  }
}
